@@ -31,7 +31,7 @@ class AmenityListHandler(o.SimpleHandler):
 
 if __name__ == '__main__':
     if len(sys.argv) != 2:
-        print "Usage: python amenity_list.py <osmfile>"
+        print("Usage: python amenity_list.py <osmfile>")
         sys.exit(-1)
 
     handler = AmenityListHandler()
