@@ -1,6 +1,7 @@
+
+#include <cassert>
 #include <time.h>
 #include <boost/python.hpp>
-#include <datetime.h>
 
 #include <osmium/osm.hpp>
 #include <osmium/osm/entity_bits.hpp>
@@ -30,21 +31,20 @@ inline const char member_item_type(osmium::RelationMember& obj)
 // Converter for osmium::Timestamp -> datetime.datetime
 struct Timestamp_to_python {
     static PyObject* convert(osmium::Timestamp const& s) {
-        struct tm tm;
-        time_t sse = s.seconds_since_epoch();
-        gmtime_r(&sse, &tm);
-
-        return boost::python::incref(
-                PyDateTime_FromDateAndTime(tm.tm_year + 1900, tm.tm_mon + 1,
-                                           tm.tm_mday, tm.tm_hour, tm.tm_min,
-                                           tm.tm_sec, 0));
+#if PY_VERSION_HEX >= 0x03000000
+        static auto fconv = boost::python::import("datetime").attr("datetime").attr("fromtimestamp");
+        static boost::python::object utc = boost::python::import("datetime").attr("timezone").attr("utc");
+        return boost::python::incref(fconv(s.seconds_since_epoch(), utc).ptr());
+#else
+        static auto fconv = boost::python::import("datetime").attr("datetime").attr("utcfromtimestamp");
+        return boost::python::incref(fconv(s.seconds_since_epoch()).ptr());
+#endif
     }
 };
 
 
 BOOST_PYTHON_MODULE(_osm)
 {
-    PyDateTime_IMPORT;
     using namespace boost::python;
     docstring_options doc_options(true, true, false);
 
